@@ -1,4 +1,4 @@
-/* $Id: gucharmap-table.c,v 1.39 2005/11/25 10:05:08 behdad Exp $ */
+/* $Id: gucharmap-table.c,v 1.41 2006/07/24 23:06:31 behdad Exp $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -472,6 +472,8 @@ chartable_accessible_factory_class_init (AtkObjectFactoryClass *clazz)
 {
   clazz->create_accessible = chartable_accessible_factory_create_accessible;
   clazz->get_accessible_type = chartable_accessible_factory_get_accessible_type;
+
+  _gucharmap_intl_ensure_initialized ();
 }
 
 static GType
@@ -1010,20 +1012,20 @@ gucharmap_table_class_init (GucharmapTableClass *clazz)
   gucharmap_table_signals[ACTIVATE] =
       g_signal_new ("activate", gucharmap_table_get_type (), G_SIGNAL_RUN_FIRST,
                     G_STRUCT_OFFSET (GucharmapTableClass, activate),
-                    NULL, NULL, gucharmap_marshal_VOID__UINT, G_TYPE_NONE, 
+                    NULL, NULL, _gucharmap_marshal_VOID__UINT, G_TYPE_NONE, 
 		    1, G_TYPE_UINT);
 
   gucharmap_table_signals[SET_ACTIVE_CHAR] =
       g_signal_new ("set_active_char", gucharmap_table_get_type (), 
                     G_SIGNAL_RUN_FIRST,
                     G_STRUCT_OFFSET (GucharmapTableClass, set_active_char),
-                    NULL, NULL, gucharmap_marshal_VOID__UINT, G_TYPE_NONE, 
+                    NULL, NULL, _gucharmap_marshal_VOID__UINT, G_TYPE_NONE, 
 		    1, G_TYPE_UINT);
 
   gucharmap_table_signals[STATUS_MESSAGE] =
       g_signal_new ("status-message", gucharmap_table_get_type (), G_SIGNAL_RUN_FIRST,
                     G_STRUCT_OFFSET (GucharmapTableClass, status_message),
-                    NULL, NULL, gucharmap_marshal_VOID__STRING, G_TYPE_NONE, 
+                    NULL, NULL, _gucharmap_marshal_VOID__STRING, G_TYPE_NONE, 
 		    1, G_TYPE_STRING);
 }
 
