@@ -1,4 +1,4 @@
-/* $Id: gucharmap-window.c,v 1.77 2006/07/24 23:23:05 behdad Exp $ */
+/* $Id: gucharmap-window.c,v 1.78 2006/08/25 12:56:51 fwang Exp $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -465,12 +465,12 @@ view_by (GtkAction        *action,
     {
       case VIEW_BY_SCRIPT:
       	gucharmap_charmap_set_chapters (guw->charmap, GUCHARMAP_CHAPTERS (gucharmap_script_chapters_new ()));
-	chapters_set_labels ("Next Script", "Previous Script", guw);
+	chapters_set_labels (_("Next Script"), _("Previous Script"), guw);
 	break;
       
       case VIEW_BY_BLOCK:
         gucharmap_charmap_set_chapters (guw->charmap, GUCHARMAP_CHAPTERS (gucharmap_block_chapters_new ()));
-	chapters_set_labels ("Next Block", "Previous Block", guw);
+	chapters_set_labels (_("Next Block"), _("Previous Block"), guw);
 	break;
       
       default:
@@ -624,7 +624,7 @@ make_menu (GucharmapWindow *guw)
 	break;
       
       case CHAPTERS_BLOCK:
-        chapters_set_labels ("Next Block", "Previous Block", guw);
+        chapters_set_labels (_("Next Block"), _("Previous Block"), guw);
 	break;
       
       default:
