@@ -1,6 +1,6 @@
-/* $Id: gucharmap.h,v 1.1 2003/05/04 22:14:23 nlevitt Exp $ */
+/* $Id: gucharmap.h,v 1.7 2004/01/30 07:33:04 nlevitt Exp $ */
 /*
- * Copyright (c) 2003  Noah Levitt <nlevitt аt columbia.edu>
+ * Copyright (c) 2004 Noah Levitt
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -17,16 +17,19 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
-
 #ifndef GUCHARMAP_H
 #define GUCHARMAP_H
 
-
 #include <gucharmap/gucharmap-table.h>
 #include <gucharmap/gucharmap-charmap.h>
 #include <gucharmap/gucharmap-window.h>
 #include <gucharmap/gucharmap-unicode-info.h>
 #include <gucharmap/gucharmap-mini-fontsel.h>
-
+#include <gucharmap/gucharmap-codepoint-list.h>
+#include <gucharmap/gucharmap-script-codepoint-list.h>
+#include <gucharmap/gucharmap-chapters.h>
+#include <gucharmap/gucharmap-block-chapters.h>
+#include <gucharmap/gucharmap-script-chapters.h>
+#include <gucharmap/gucharmap-search-dialog.h>
 
 #endif /* #ifndef GUCHARMAP_H */
